<template>
	<div
		class="min-w-[320px] w-max-[520px] border-2 rounded-lg border-solid border-gray-100 bg-white p-3 shadow-md relative hover:border-blue-500 group"
	>
		<Handle :id="targetHandleId" type="source" :position="Position.Left" />
		<div
			class="group-hover:visible invisible flex absolute divide-y-[1.5px] divide-solid divide-gray-100 rounded-lg right-0 -top-0.5 translate-y-[-100%]"
			style="box-shadow: 0 0 15px #dbdee6"
		>
			<el-tooltip effect="dark" content="复制" placement="top">
				<div
					class="flex content-center items-center border-x-0 p-1 hover:bg-gray-200 active:bg-gray-300 cursor-pointer"
					@click="handleClickDuplicateBtn"
				>
					<span class="ywifont !text-[20px] mb-1 p-1.5 ywicon-copy"></span>
				</div>
			</el-tooltip>
			<el-tooltip effect="dark" content="删除" placement="top">
				<div
					@click="clickDeleteBtn"
					class="flex content-center items-center border-x-0 p-1 hover:bg-gray-200 active:bg-gray-300 hover:text-red-400 cursor-pointer"
				>
					<span class="ywifont !text-[20px] mb-1 p-1.5 ywicon-shanchu"></span>
				</div>
			</el-tooltip>
		</div>
		<div class="flex flex-col gap-y-2">
			<div class="flex justify-between flex-0">
				<div class="flex items-center gap-x-2">
					<img src="/@/components/vue-flow/ui/assets/images/icon_Start.png" class="h-4 w-4" alt="Start icon" />
					<div class="flex flex-col gap-y-1">
						<p v-if="!titleIsEdit" class="text-xl font-bold text-gray-500" @click="titleIsEdit = true">{{ data.title }}</p>
						<el-input v-elInputFocus="false" v-else v-model="data.title" @blur="() => (titleIsEdit = false)"></el-input>
					</div>
				</div>
			</div>

			<div class="flex-auto gap-y-2 flex-col flex nodrag w-full">
				<!-- <div class="text-lg font-bold">提示词</div> -->

				<div class="flex-column gap-y-1.5 w-full">
					<span class="self-start text-gray-500">{{ VueFlowHelper.getParams(outputParams, 'output_msg').label }}</span>
					<el-input
						v-model="VueFlowHelper.getParams(outputParams, 'output_msg').value.msg"
						type="textarea"
						:rows="4"
						:placeholder="VueFlowHelper.getParams(outputParams, 'output_msg').placeholder"
						autocomplete="off"
					>
					</el-input>
				</div>
				<div class="flex-column gap-y-1.5 w-full">
					<span class="self-start text-gray-500">{{ VueFlowHelper.getParams(outputParams, 'output_result').label }}</span>

					<el-radio-group v-model="VueFlowHelper.getParams(outputParams, 'output_result').value.type">
						<el-radio v-for="item in Object.keys(interactionTypeMap)" :key="item" :value="item">{{
							interactionTypeMap[item]
						}}</el-radio>
					</el-radio-group>
					<el-input
						v-model="VueFlowHelper.getParams(outputParams, 'output_result').value.value"
						type="textarea"
						:rows="4"
						v-if="VueFlowHelper.getParams(outputParams, 'output_result').value.type === InteractionType.Input"
					>
					</el-input>

					<div
						class="self-start w-full flex-col flex items-start gap-2"
						v-else-if="VueFlowHelper.getParams(outputParams, 'output_result').value.type === InteractionType.Select"
					>
						<div class="flex-column gap-2">
							<div
								class="text-gray-400 cursor-not-allowed border border-solid rounded-lg border-gray-300 py-3 pl-3 pr-2 items-center justify-between flex group/option relative"
								:key="item.id"
								v-for="(item, index) in VueFlowHelper.getParams(outputParams, 'output_result').options"
							>
								<span>{{ item.label }}</span>
								<span
									@click="delOption(index)"
									class="cursor-pointer group-hover/option:visible invisible ywifont ywicon-shanchu text-red-500"
								></span>
							</div>
						</div>

						<div v-if="isEditStatus" class="flex-items-center w-full">
							<el-input class="flex-auto" v-model="tmpEditValue"></el-input>
							<el-button class="flex-0 ml-2" type="success" @click="confirmClick">确定 </el-button>
						</div>
						<el-button v-else type="primary" @click="addOptionClick">添加选项</el-button>
					</div>
				</div>
			</div>
		</div>
		<Handle v-if="VueFlowHelper.getParams(outputParams, 'output_result').value.type === InteractionType.Input ||VueFlowHelper.getParams(outputParams, 'output_result').value.type === InteractionType.None" :id="sourceHandleId" type="source" :position="Position.Right" />
	</div>

	<!-- <div>
		<span>起始</span>

		<Handle type="source" :position="Position.Right" />
	</div> -->
</template>

<script lang="ts" setup>
import { Handle, Position, useNode, useVueFlow } from '@vue-flow/core';
import { ref } from 'vue';

import type { NodeProps } from '@vue-flow/core';
import { nextTick } from 'vue';
import { VueFlowHelper } from '../../VueFlowHelper';
import { InteractionType, interactionTypeMap } from '../../vueFlowEnum';
import { LLMNodeData, LLMNodeEvents } from './index';
import { deepClone } from '/@/utils/other';
defineProps<NodeProps<LLMNodeData, LLMNodeEvents>>();

const node = useNode();
const sourceHandleId = ref(VueFlowHelper.getHandleId(node.node, 'source'));
const targetHandleId = ref(VueFlowHelper.getHandleId(node.node, 'target'));

const data = ref(node.node.data);

const titleIsEdit = ref(false);

const outputParams = ref(VueFlowHelper.getGroupParam(data.value, 0));

const { removeNodes, nodes, addNodes } = useVueFlow();

function handleClickDuplicateBtn() {
	const { type, position, data } = node.node;
	const newNode = {
		id: VueFlowHelper.genGeometryId(),
		type,
		position: {
			x: position.x + 100,
			y: position.y + 100,
		},
		data: deepClone(data),
	};
	addNodes(newNode);
}
const clickDeleteBtn = () => {
	removeNodes(node.id);
};
const addOptionClick = () => {
	isEditStatus.value = true;
};

const confirmClick = () => {
	isEditStatus.value = false;

	addOption(tmpEditValue.value);
	nextTick(() => {
		tmpEditValue.value = '';
	});
};
const addOption = (val) => {
	const options = VueFlowHelper.getParams(outputParams.value, 'output_result').options;
	options.push({
		id: VueFlowHelper.genId(),
		label: val,
		value: '',
	});
};

const delOption = (index) => {
	const options = VueFlowHelper.getParams(outputParams.value, 'output_result').options;
	options.splice(index);
};

const isEditStatus = ref(false);
const tmpEditValue = ref('');
</script>
